//---------------------------------------------------------------------------

#include <ExptIntf.hpp>
#include <EditIntf.hpp>
#include <ToolIntf.hpp>

#pragma hdrstop

#include "EditorIntf.h"

//---------------------------------------------------------------------------

#pragma package(smart_init)

const int buflen = 16383;
char buffer[buflen + 1];

TIModuleInterface *fModuleInterface = NULL;
TIEditorInterface *fEditorInterface[2] = { NULL, NULL };
TIEditReader *ActualReader = NULL;
TIEditWriter *ActualWriter = NULL;

//---------------------------------------------------------------------------

__fastcall TEditorIntf::TEditorIntf(void)
{
  String file = ToolServices->GetProjectName();
  if (file == "")
  {
    MessageBox(0, "Sorry, a project must be open", "C++ Indent", MB_OK);
    return;
  }

  file = ToolServices->GetCurrentFile();
  String ext = LowerCase(ExtractFileExt(file));
  if ((ext != ".c") && (ext != ".cpp") && (ext != ".h") && (ext != ".hpp"))
  {
    MessageBox(0, "Sorry, must be a C++ file", "C++ Indent", MB_OK);
    return;
  }

  fModuleInterface = ToolServices->GetModuleInterface(file);

  if (fModuleInterface)
  {
    fEditorInterface[0] = fModuleInterface->GetEditorInterface();
    fEditorInterface[1] = fModuleInterface->GetAuxEditorInterface();
  }
}

__fastcall TEditorIntf::~TEditorIntf(void)
{
  if (fEditorInterface[0])
    delete fEditorInterface[0];

  if (fEditorInterface[1])
    delete fEditorInterface[1];

  //if (fModuleInterface)delete fModuleInterface; //|

  fModuleInterface = NULL;
  fEditorInterface[0] = NULL;
  fEditorInterface[1] = NULL;
}

//---------------------------------------------------------------------------
int __fastcall TEditorIntf::GetTextLen(int FileIndex)
{
  if (!fEditorInterface[FileIndex])
    return 0;

  ActualReader = fEditorInterface[FileIndex]->CreateReader();

  if (ActualReader == NULL)
    return 0;

  int textlen = 0, readlen;
  do
  {
    readlen = ActualReader->GetText(textlen, buffer, buflen);
    textlen += readlen;
  }
  while (readlen == buflen);

  delete ActualReader;
  return textlen;
}

void __fastcall TEditorIntf::GetText(int FileIndex, char *text) //, int length)
{
  if (!fEditorInterface[FileIndex])
    return;

  ActualReader = fEditorInterface[FileIndex]->CreateReader();

  if (ActualReader == NULL)
    return;

  int pos = 0, readlen;
  do
  {
    readlen = ActualReader->GetText(pos, text + pos, buflen);
    pos += readlen;
  }
  while (readlen == buflen);

  //if (pos != length)
  //  MessageBox(0, "pos!=length", "C++ Indent", MB_OK);

  delete ActualReader;
}

void __fastcall TEditorIntf::SetText(int FileIndex, char *text, int deletelen)
{
  if (!fEditorInterface[FileIndex])
    return;

  ActualWriter = fEditorInterface[FileIndex]->CreateUndoableWriter();

  if (ActualWriter == NULL)
    return;

  ActualWriter->CopyTo(0);
  ActualWriter->DeleteTo(deletelen - 1);
  ActualWriter->Insert(text);
  delete ActualWriter;
}

//---------------------------------------------------------------------------

